@@ -13,7 +13,7 @@ BEGIN {
         require Win32;
     }
 }
-our $VERSION = '1.08_01';
+our $VERSION = '1.08_02';
 
 sub _ANY_PORT           { return 0 }
 sub _GETPWUID_DIR_INDEX { return 7 }
@@ -172,6 +172,9 @@ sub new {
       ;    # the last folder specified for a download
     $profile->set_value( 'browser.places.importBookmarksHTML',  'true',  0 );
     $profile->set_value( 'browser.reader.detectedFirstArticle', 'true',  0 );
+    $profile->set_value( 'browser.region.network.scan', 'false',  0 );
+    $profile->set_value( 'browser.region.network.url', q[],  0 );
+    $profile->set_value( 'browser.region.update.enabled', 'false',  0 );
     $profile->set_value( 'browser.shell.checkDefaultBrowser',   'false', 0 );
     $profile->set_value( 'browser.showQuitWarning',             'false', 0 );
     $profile->set_value( 'browser.startup.homepage', 'about:blank',      1 );
@@ -463,7 +466,7 @@ Firefox::Marionette::Profile - Represents a prefs.js Firefox Profile
 
 =head1 VERSION
 
-Version 1.08_01
+Version 1.08_02
 
 =head1 SYNOPSIS
 
